package cc.bnblogs.usercenterbackend.exception;

import cc.bnblogs.usercenterbackend.common.ErrorCode;

/**
 * @description: 自定义异常类，相比默认的异常类抛出更多信息，同时支持更多自定义构造函数
 * @author: zfp@bnblogs.cc
 * @date: 2023/3/15 15:44
 */
public class BusinessException extends RuntimeException {
    private final int code;
    private final String description;

    /**
     * 状态码和描述信息完全自定义
     * @param message
     * @param code 状态码
     * @param description 详情
     */
    public BusinessException(String message, int code, String description) {
        super(message);
        this.code = code;
        this.description = description;
    }

    /**
     * 接收错误码，返回异常信息
     * @param errorCode
     */
    public BusinessException(ErrorCode errorCode) {
        super(errorCode.getMessage());
        this.code = errorCode.getCode();
        this.description = errorCode.getDescription();
    }

    /**
     * 修改错误码默认的详情信息
     * @param errorCode 错误业务码
     * @param description 详情
     */
    public BusinessException(ErrorCode errorCode,String description) {
        super(errorCode.getMessage());
        this.code = errorCode.getCode();
        this.description = description;
    }

    public int getCode() {
        return code;
    }

    public String getDescription() {
        return description;
    }
}
